@@ -81,8 +81,6 @@ class Assembly:
 
         self.dofs = self._check_dof()
 
-        self.xi = 0.00  # modal damping coefficient, default 0 -> no damping
-
     def __repr__(self):
         pass
 
@@ -136,6 +134,7 @@ class Assembly:
         ndarray
             The stiffness matrix
         """
+
         K = np.zeros((self.dofs, self.dofs))
 
         if self.shaft_elements is not None:
@@ -161,6 +160,7 @@ class Assembly:
         """
         Assembles the stiffness matrix when gears are not considered
         """
+
         K = np.zeros((self.dofs, self.dofs))
 
         if self.shaft_elements is not None:
@@ -179,6 +179,7 @@ class Assembly:
         ndarray
             The damping matrix assembled with component specific damping coefficients
         """
+
         C = np.zeros((self.dofs, self.dofs))
 
         if self.shaft_elements is not None:
@@ -247,6 +248,7 @@ class Assembly:
         ndarray
             The gear constraint transformation matrix
         """
+
         r, c = E.shape
         T = np.eye(r)
         for i in range(c):
@@ -331,7 +333,10 @@ class Assembly:
 
         Parameters
         ----------
-        TODO: M, K included in parameters for debugging reasons
+        M : ndarray
+            Assembly mass matrix, included for debugging reasons
+        K : ndarray
+            Assembly stiffness matrix, included for debugging reasons
         xi : float, optional
             Modal damping factor, default is 0
 
@@ -340,8 +345,7 @@ class Assembly:
         ndarray
             The full damping matrix
         """
-        if self.xi is None:
-            xi = self.xi
+
         omegas, phi = LA.eig(K, M)
         omegas = np.absolute(omegas)
 
@@ -358,7 +362,7 @@ class Assembly:
         I = phi_norm.T @ M @ phi_norm
 
         # The diagonal modal damping matrix is achieved by applying the modal damping
-        C_modal_elements = 2 * self.xi * np.sqrt(omegas)
+        C_modal_elements = 2 * xi * np.sqrt(omegas)
         C_modal_diag = np.diag(C_modal_elements)
 
         # The final damping matrix
@@ -391,6 +395,7 @@ class Assembly:
         ndarray
             Steady-state coefficient vector
         """
+
         if type(amplitudes) is np.ndarray:
             Z = np.zeros(amplitudes.shape)
             a, b = np.zeros(amplitudes.shape), np.zeros(amplitudes.shape)
@@ -512,6 +517,7 @@ class Assembly:
         complex ndarray
             The eigenvectors of the undamped assembly
         """
+
         lam, vec = self._eig(self.K(), self.M())
 
         return lam, vec
@@ -529,6 +535,7 @@ class Assembly:
         ndarray
             The damping ratios
         """
+
         A, B = self.state_matrix()
         lam, vec = self._eig(A, B)
 
@@ -550,6 +557,7 @@ class Assembly:
         complex ndarray
             Solved eigenvectors
         """
+
         lam, vec = LA.eig(A, B)
 
         return lam, vec
@@ -563,6 +571,7 @@ class Assembly:
         complex ndarray
             Eigenmode array, columns correspond to modes left to right starting from zero
         """
+
         A, B = self.state_matrix()
         lam, vec = self._eig(A, B)
 
@@ -586,6 +595,7 @@ class Assembly:
         int
             Number of degrees of freedom of the assembly
         """
+
         nodes = set()
         if self.shaft_elements is not None:
             for element in self.shaft_elements:
@@ -611,6 +621,7 @@ class Assembly:
         OUTDATED! See module excitations
         Input matrix of the state-space model
         """
+
         # u1 at node '0', u2 at node 'n'
 
         if np.array([u1]) is None:
@@ -665,6 +676,7 @@ class Assembly:
         StateSpaceContinuous
             A continuous time-invariant state-space model of the assembly
         """
+
         M, K = self.M(), self.K()
         try:
             C = self.C_modal(M, K, xi=self.xi)
@@ -735,6 +747,7 @@ class Assembly:
         """
         System model in the ltis-format
         """
+
         M, K = self.M(), self.K()
         if modal_damping:
             C = self.C_modal(M, K, xi=self.xi)
